import string
import unittest
from mock import patch

from auklet.monitoring import MonitoringBase, Monitoring


class TestMonitoringBase(unittest.TestCase):
    def setUp(self):
        self.monitoring_base = MonitoringBase()

    def test_start(self):
        self.assertRaises(
            NotImplementedError, lambda: self.monitoring_base.start())
        self.assertRaises(
            RuntimeError, lambda: self.monitoring_base.start())

    def test_frame_stack(self):
        class Frame:
            f_back = None
        frame = Frame()
        self.assertNotEqual(
            self.monitoring_base.frame_stack(frame=frame), None)

    def test_results(self):
        self.monitoring_base._cpu_time_started = \
            self.monitoring_base._wall_time_started = None
        self.assertRaises(TypeError, lambda: self.monitoring_base.result())
        self.monitoring_base._cpu_time_started = \
            self.monitoring_base._wall_time_started = 0
        self.assertNotEqual(str(self.monitoring_base.result()), "(0, 0, 0)")



class TestMonitoring(unittest.TestCase):
    def setUp(self):
        self.function = Monitoring(
            apikey="",
            app_id="",
            base_url="https://api-staging.io",
            monitoring=True)

    def test_start(self):
        self.assertTrue(self.function.monitor)
        self.function.monitor = False
        self.assertFalse(self.function.monitor)
        self.function.monitor = True

    def test_sample(self):
        class CoCode:
            co_code = None
            co_firstlineno = None
            co_name = None
        class Frame:
            f_back = None
            f_code = CoCode()
        frame = Frame()

        def update_hash(self, stack):
            global test_sample_stack
            test_sample_stack = stack

        with patch('auklet.stats.MonitoringTree.update_hash', new=update_hash):
            self.function.sample(frame=frame, event="event")
            self.assertEqual(
                str(test_sample_stack[0]).strip(')').split(", ")[1], "False")
            self.function.sample(frame=frame, event="call")
            self.assertTrue(test_sample_stack)
            self.assertEqual(
                str(test_sample_stack[0]).strip(')').split(", ")[1], "True")

    def test_run(self):
        self.function.run()
        self.assertEqual(self.function.sampler.start(self.function), None)
        self.function.sampler.stop()
        self.function.sampler.start(self.function)
        self.assertEqual(self.function.sampler.stop(), None)

    def test_log(self):
        self.assertEqual(self.function.log(msg="msg", data_type="str"), None)


if __name__ == '__main__':
    unittest.main()



import time
import unittest
from mock import patch

from auklet.monitoring.sampling import AukletSampler
from auklet.monitoring import Monitoring
from auklet.errors import AukletConfigurationError
from auklet.stats import MonitoringTree
from auklet.base import Client


class TestAukletSampler(unittest.TestCase):
    def setUp(self):
        def _get_kafka_brokers(self):
            self.brokers = ["api-staging.auklet.io:9093"]
            self.producer_types = {
                "monitoring": "profiling",
                "event": "events",
                "log": "logging"
            }
        def _open_auklet_url(self, url):
            _ = url

        self.patcher = patch(
            'auklet.base.Client._get_kafka_brokers', new=_get_kafka_brokers)
        self.patcher2 = patch(
            'auklet.base.Client._open_auklet_url', new=_open_auklet_url)
        self.patcher.start()
        self.patcher2.start()

        self.monitoring = Monitoring(
            apikey="", app_id="", base_url="https://api-staging.auklet.io/")

        self.client = Client(
            apikey="", app_id="", base_url="https://api-staging.auklet.io/")

        self.monitoring_tree = MonitoringTree()
        self.monitoring_tree.root_func = \
            {"key": self.monitoring_tree.get_filename}
        self.tree = self.monitoring_tree
        self.auklet_sampler = AukletSampler(
            client=self.client, tree=self.tree)

    def tearDown(self):
        self.patcher.stop()
        self.patcher2.stop()

    def test_profile(self):
        class CoCode:
            co_code = None
            co_firstlineno = None
            co_name = None

        class Frame:
            f_back = None
            f_code = CoCode()

        def produce(self, event):
            global test_profile_event
            test_profile_event = event

        with patch('auklet.base.Client.produce', new=produce):
            self.auklet_sampler.prev_diff = 1
            self.auklet_sampler._profile(
                profiler=self.monitoring, frame=Frame(), event="", arg="")
            self.assertNotEqual(test_profile_event, None)


    def test_handle_exc(self):
        def build_event_data(self, type="", value="", traceback=""):
            _ = type
            _ = value
            _ = traceback
            return {"commitHash": "", "id": "", "tree":
                    {"lineNumber": 1,
                     "nSamples": 173756,
                     "functionName": "root",
                     "nCalls": 1,
                     "callees": []},
                    "publicIP": "0.0.0.0",
                    "timestamp": 1530555317012,
                    "application": "tyJSjp3aSyxxdoGAtqsMT4",
                    "macAddressHash": ""}

        def produce(self, event, topic):
            global test_handle_exc_event
            test_handle_exc_event = event
            _ = topic

        with patch('auklet.base.Client.build_event_data',
                   new=build_event_data):
            with patch('auklet.base.Client.produce', new=produce):
                self.auklet_sampler.handle_exc(
                    type=None, value="", traceback="")
                self.assertEqual(build_event_data(self), test_handle_exc_event)

    def test_run(self):
        self.assertNotEqual(self.auklet_sampler.run(profiler=""), None)


if __name__ == '__main__':
    unittest.main()



import unittest

from auklet.errors import AukletException, AukletConnectionError, AukletConfigurationError


class TestAukletException(unittest.TestCase):
    def test_auklet_exception(self):
        self.assertEqual(
            str(AukletException(Exception)), "<class 'Exception'>")


class TestAukletConnectionError(unittest.TestCase):
    def test_auklet_connection_error(self):
        self.assertEqual(str(AukletConnectionError()), "")


class TestAukletConfigurationError(unittest.TestCase):
    def test_auklet_configuration_error(self):
        self.assertEqual(str(AukletConfigurationError()), "")


if __name__ == '__main__':
    unittest.main()



import os
import unittest
from mock import patch

from tests import data_factory

from auklet.stats import Function, Event, MonitoringTree, SystemMetrics


class TestFunction(unittest.TestCase):
    def get_test_child(self):
        class TestChild:
            func_name = "test_child"
            file_path = "file_path"
        return TestChild

    def setUp(self):
        self.function = Function(line_num=0, func_name="UnitTest")

    def test___str__(self):
        self.assertNotEqual(self.function.__str__(), None)

    def test___iter__(self):
        for t in self.function.__iter__():
            self.assertNotEqual(t, None)

    def test_has_child(self):
        self.assertFalse(self.function.has_child(test_child=""))
        self.function.children.append(self.get_test_child())
        self.assertNotEqual(
            self.function.has_child(test_child=self.get_test_child()), False)


class TestEvent(unittest.TestCase):
    def get_filename(self, code="code", frame="frame"):
        _ = code
        _ = frame
        return ""

    def get_traceback(self):
        class Code:
            co_name = None
        class Frame:
            f_code = Code()
            f_lineno = 0
            f_locals = {"key": "value"}
        class Traceback:
            tb_lineno = 0
            tb_frame = Frame()
            tb_next = None
        return Traceback

    def setUp(self):
        self.tree = MonitoringTree()
        self.patcher = patch(
            'auklet.stats.MonitoringTree.get_filename', new=self.get_filename)
        self.patcher.start()
        self.event = Event(
            exc_type=str, tb=self.get_traceback(),
            tree=self.tree, abs_path="abs_path")

    def tearDown(self):
        self.patcher.stop()

    def test___iter__(self):
        for t in self.event.__iter__():
            self.assertNotEqual(t, None)

    def test_filter_frame(self):
        self.assertTrue(self.event._filter_frame(file_name="auklet"))
        self.assertFalse(self.event._filter_frame(file_name=""))

    def test_convert_locals_to_string(self):
        self.assertNotEqual(
            self.event._convert_locals_to_string(
                local_vars={"key": "value"}), None)
        self.assertNotEqual(
            self.event._convert_locals_to_string(
                local_vars={"key": True}), None)

    def test_build_traceback(self):
        def _filter_frame(self, file_name):
            _ = file_name
            return True

        with patch('auklet.stats.Event._filter_frame', new=_filter_frame):
            self.event._build_traceback(
                trace=self.get_traceback(), tree=self.tree)
            self.assertEqual(self.event.trace, [])

        def _filter_frame(self, file_name):
            _ = file_name
            return False

        with patch('auklet.stats.Event._filter_frame', new=_filter_frame):
            self.event._build_traceback(
                trace=self.get_traceback(), tree=self.tree)
            self.assertEqual(self.event.trace,
                             [{'functionName': None,
                               'filePath': '',
                               'lineNumber': 0,
                               'locals': {'key': 'value'}}])

        def get_filename(self, f_code, frame):
            _ = f_code
            _ = frame
            return "abs_path"
        with patch('auklet.stats.MonitoringTree.get_filename',
                   new=get_filename):
            self.event._build_traceback(
                trace=self.get_traceback(), tree=self.tree)
            self.assertEqual(self.event.trace,
                             [{'functionName': None,
                               'filePath': '',
                               'lineNumber': 0,
                               'locals': {'key': 'value'}}])


class TestMonitoringTree(unittest.TestCase):
    def get_code(self):
        class Code:
            co_code = "file_name"
            co_firstlineno = 0
            co_name = ""
        return Code

    def get_frame(self):
        class Frame:
            f_code = self.get_code()
        frame = []
        frame.append(Frame)
        frame.append(Frame)
        return frame

    def get_root_function(self):
        return {'callees': [],
                'filePath': None,
                'functionName': 'root',
                'lineNumber': 1,
                'nCalls': 1,
                'nSamples': 1}

    def get_parent(self):
        pass

    def get_new_parent(self):
        class Parent:
            children = []
        return Parent

    def setUp(self):
        self.monitoring_tree = MonitoringTree()
        self.function = Function(line_num=0, func_name="UnitTest")

    def test_get_filename(self):
        self.monitoring_tree.cached_filenames.clear()
        self.monitoring_tree.cached_filenames['file_name'] = "file_name"
        self.assertEqual(
            self.monitoring_tree.get_filename(
                code=self.get_code(), frame="frame"), self.get_code().co_code)

    def test_create_frame_function(self):
        self.assertNotEqual(
            self.monitoring_tree._create_frame_func(
                frame=self.get_frame()), None)

    def test_filter_frame(self):
        self.assertTrue(self.monitoring_tree._filter_frame(file_name=None))
        self.assertFalse(self.monitoring_tree._filter_frame(file_name=""))
        self.assertTrue(
            self.monitoring_tree._filter_frame(file_name="site-packages"))

    def test__build_tree(self):
        class Frame:
            class Code:
                co_code = ""
                co_firstlineno = 0
                co_name = ""
            f_code = Code()
        frame = Frame()

        result = str(self.monitoring_tree._build_tree(
            new_stack=[[frame, frame]]))

        self.assertEqual(
            result, str(data_factory.StackTraceFactory()))

        def _filter_frame(self, file_name):
            return False

        with patch('auklet.stats.MonitoringTree._filter_frame',
                   new=_filter_frame):
            result = str(self.monitoring_tree._build_tree(
                new_stack=[[frame, frame]]))

            self.assertEqual(
                result, str(data_factory.SingleNestedStackTraceFactory()))

    def test_update_sample_count(self):
        self.assertTrue(
            self.monitoring_tree._update_sample_count(
                parent=None, new_parent=self.get_new_parent()))

        class Parent:
            calls = 0
            samples = 0
            def has_child(self, new_child):
                class Child:
                    calls = 0
                    samples = 0

                child = Child
                return child
        parent = Parent()

        class NewParent:
            class NewChild:
                calls = 0
            children = [NewChild]
        new_parent = NewParent()

        with self.assertRaises(AttributeError) as error:
            self.monitoring_tree._update_sample_count(
                parent=parent, new_parent=new_parent)
        self.assertEqual("type object 'NewChild' has no attribute 'children'",
                         str(error.exception))

        class Parent:
            calls = 0
            samples = 0
            def has_child(self, new_child):
                return False
        parent = Parent()

        with self.assertRaises(AttributeError) as error:
            self.monitoring_tree._update_sample_count(
                parent=parent, new_parent=new_parent)
        self.assertEqual("'Parent' object has no attribute 'children'",
                         str(error.exception))


    def test_update_hash(self):
        self.assertNotEqual(
            self.monitoring_tree.update_hash(new_stack=""), None)

        def _update_sample_count(self, parent, new_parent):
            global test_update_hash_parent
            test_update_hash_parent = parent

        self.monitoring_tree.root_func = self.function
        with patch('auklet.stats.MonitoringTree._update_sample_count',
                   new=_update_sample_count):
            self.monitoring_tree.update_hash(new_stack="")

        self.assertNotEqual(test_update_hash_parent, None)

    def test_clear_root(self):
        self.monitoring_tree.root_func = self.get_root_function()
        self.assertTrue(self.monitoring_tree.clear_root())
        self.assertEqual(self.monitoring_tree.root_func, None)

    def test_build_tree(self):
        self.monitoring_tree.root_func = self.get_root_function()
        self.assertNotEqual(
            self.monitoring_tree.build_tree(app_id="app_id"), None)


class TestSystemMetrics(unittest.TestCase):
    def setUp(self):
        self.system_metrics = SystemMetrics()

    def test_update_network(self):
        self.system_metrics.update_network(interval=1)
        self.assertNotEqual(self.system_metrics.prev_inbound, 0)


if __name__ == '__main__':
    unittest.main()



import os
import unittest
from mock import patch, Mock
from datetime import datetime
import json

from urllib.error import HTTPError

from tests import data_factory

from kafka.errors import KafkaError
from ipify.exceptions import IpifyException

from auklet.base import *
from auklet.stats import MonitoringTree
from auklet.errors import AukletConfigurationError


class TestClient(unittest.TestCase):
    data = str(data_factory.MonitoringDataFactory())
    def setUp(self):
        def _get_kafka_brokers(self):
            self.brokers = ["api-staging.auklet.io:9093"]
            self.producer_types = {
                "monitoring": "profiling",
                "event": "events",
                "log": "logging"
            }
        self.patcher = patch(
            'auklet.base.Client._get_kafka_brokers', new=_get_kafka_brokers)
        self.patcher.start()
        self.client = Client(
            apikey="", app_id="", base_url="https://api-staging.auklet.io/")
        self.monitoring_tree = MonitoringTree()

    def tearDown(self):
        self.patcher.stop()

    def test___init__(self):
        def _get_kafka_certs(self):
            return True

        class KafkaProducer(object):
            global test__init__producer
            test__init__producer = True

        with patch('auklet.base.Client._get_kafka_certs',
                   new=_get_kafka_certs):
            with patch('kafka.KafkaProducer', new=KafkaProducer):
                self.client.__init__()
                self.assertTrue(test__init__producer)

    def test_create_file(self):
        files = ['.auklet/local.txt', '.auklet/limits',
                 '.auklet/usage', '.auklet/communication']
        for f in files:
            file = False
            if os.path.isfile(f):
                file = True
            self.assertTrue(file)

    def test_build_url(self):
        extension = str("private/devices/config/")
        self.assertEqual(
            self.client._build_url(extension),
            self.client.base_url + extension)

    def test_open_auklet_url(self):
        url = self.client.base_url + "private/devices/config/"
        self.assertRaises(
            AukletConfigurationError,
            lambda: self.client._open_auklet_url(url))
        url = "http://google.com/"
        self.assertNotEqual(self.client._open_auklet_url(url), None)

    def test_get_config(self):
        pass

    def test_get_kafka_brokers(self):
        pass

    def test_write_kafka_conf(self):
        filename = self.client.com_config_filename
        self.client._write_kafka_conf(info=str(data_factory.ConfigFactory()))
        self.assertGreater(os.path.getsize(filename), 0)
        open(filename, "w").close()

    def test_load_kafka_conf(self):
        filename = self.client.com_config_filename
        with open(filename, "w") as my_file:
            my_file.write(str(data_factory.ConfigFactory()))
        self.assertTrue(self.client._load_kafka_conf())
        open(filename, "w").close()

    def test_load_limits(self):
        loaded = True
        if self.client._load_limits():
            loaded = False
        self.assertTrue(loaded)

    def test_get_kafka_certs(self):
        with patch('auklet.base.Client._build_url') as mock_zip_file:
            with patch('zipfile.ZipFile') as mock_url:
                mock_url.file_list.return_value = ""
                mock_zip_file.return_value = "http://api-staging.auklet.io"
                self.assertTrue(self.client._get_kafka_certs())

    def test_write_to_local(self):
        self.client._write_to_local(self.data)
        self.assertGreater(os.path.getsize(self.client.offline_filename), 0)
        self.client._clear_file(self.client.offline_filename)

        os.system("rm -R .auklet")
        self.assertFalse(self.client._write_to_local(self.data))
        os.system("mkdir .auklet")
        os.system("touch %s" % self.client.offline_filename)
        os.system("touch .auklet/version")

    def test_clear_file(self):
        file_name = "unit_test_temp"
        with open(file_name, "w") as unit_test_temp_file:
            unit_test_temp_file.write("data")
        self.client._clear_file(file_name)
        self.assertEqual(os.path.getsize(file_name), 0)
        os.remove(file_name)

    def test_produce_from_local(self):
        def _produce(self, data, data_type):
            global test_produced_data
            test_produced_data = data
        with patch('auklet.base.Client._produce', new=_produce):
            with open(self.client.offline_filename, 'w') as offline:
                offline.write(json.dumps({'stackTrace': 'data'}))
            self.client._produce_from_local()
        self.assertEqual(test_produced_data, {'stackTrace': 'data'})

        os.system("rm -R .auklet")
        self.assertFalse(self.client._produce_from_local())
        os.system("mkdir .auklet")
        os.system("touch %s" % self.client.offline_filename)
        os.system("touch .auklet/version")

    def test_build_usage_json(self):
        data = self.client._build_usage_json()
        for value in data.values():
            self.assertNotEqual(value, None)

    def test_update_usage_file(self):
        os.system("rm -R .auklet")
        self.assertFalse(self.client._update_usage_file())
        os.system("mkdir .auklet")
        os.system("touch %s" % self.client.offline_filename)
        os.system("touch .auklet/version")

    def test_check_data_limit(self):
        self.client.offline_limit = None
        self.assertTrue(
            self.client._check_data_limit(
                data=self.data, current_use=0, offline=True))

        self.client.data_limit = None
        self.assertTrue(
            self.client._check_data_limit(data=self.data, current_use=0))

        self.client.offline_limit = self.client.data_limit = 1
        self.assertFalse(
            self.client._check_data_limit(data=self.data, current_use=0))

        self.client.data_limit = 1000
        self.client._check_data_limit(
            data=self.data, current_use=0, offline=True)
        self.assertNotEqual(self.client.offline_current, 0)

        self.client._check_data_limit(
            data=self.data, current_use=0)
        self.assertNotEqual(self.client.data_current, 0)

        self.assertTrue(
            self.client._check_data_limit(data=self.data, current_use=0))

    def test_kafka_error_callback(self):
        self.client._kafka_error_callback(msg="", error="")
        self.assertGreater(os.path.getsize(self.client.offline_filename), 0)
        self.client._clear_file(self.client.offline_filename)

    def test_update_network_metrics(self):
        self.client.update_network_metrics(1000)
        self.assertNotEqual(self.client.system_metrics, None)
        self.client.system_metrics = None

    def test_check_date(self):
        self.client.data_day = datetime.today().day
        self.client.data_current = 1000
        self.client.reset_data = True
        self.client.check_date()
        self.assertEqual(self.client.data_current, 0)
        self.assertEqual(self.client.reset_data, False)

    def test_update_limits(self):
        none = True
        cellular_data_limit = None
        storage_limit = None
        cell_plan_date = 1

        def _get_config(self):
            if none:
                return None
            else:
                return {"storage":
                        {"storage_limit": storage_limit},
                        "emission_period": 60,
                        "features":
                        {"performance_metrics": True,
                         "user_metrics": False},
                        "data":
                        {"cellular_data_limit": cellular_data_limit,
                         "normalized_cell_plan_date": cell_plan_date}}

        with patch('auklet.base.Client._get_config', new=_get_config):
            self.assertEqual(self.client.update_limits(), 60)
            none = False

            cellular_data_limit = 1000
            self.client.update_limits()
            self.assertEqual(self.client.data_limit, 1000000000.0)
            cellular_data_limit = None

            storage_limit = 1000
            self.client.update_limits()
            self.assertEqual(self.client.offline_limit, 1000000000.0)
            storage_limit = None

            cell_plan_date = 10
            self.client.update_limits()
            self.assertEqual(self.client.data_day, 10)
            cell_plan_date = 1

            self.assertEqual(self.client.update_limits(), 60000)

    def test_build_event_data(self):
        def get_mock_event(exc_type=None, tb=None, tree=None, abs_path=None):
            return {"stackTrace":
                    [{"functionName": "",
                        "filePath": "",
                        "lineNumber": 0,
                        "locals":
                        {"key": "value"}}]}

        with patch('auklet.base.Event', new=get_mock_event):
            self.assertNotEqual(
                self.client.build_event_data(
                    type=None, traceback="", tree=""), None)

    def test_build_log_data(self):
        self.assertNotEqual(
            self.client.build_log_data(
                msg='msg', data_type='data_type', level='level'), None)

    def test__produce(self):
        pass

    def test_produce(self):
        global error
        error = False

        def _produce(self, data, data_type="monitoring"):
            global test_produce_data
            test_produce_data = str(data).replace("'", '"')

        def _check_data_limit(self, data, data_current, offline=False):
            if not error or offline:
                return True
            else:
                raise KafkaError

        with patch('auklet.base.Client._produce', new=_produce):
            with patch('auklet.base.Client._check_data_limit',
                       new=_check_data_limit):
                self.client.producer = True

                with open(self.client.offline_filename, 'w') as offline:
                    offline.write(self.data)
                self.client.produce(self.data)
                self.assertEqual(test_produce_data, self.data)

                error = True
                self.client.produce(self.data)
                self.assertGreater(os.path.getsize(self.client.offline_filename), 0)

class TestRunnable(unittest.TestCase):
    def setUp(self):
        self.runnable = Runnable()

    def test_is_running(self):
        self.assertFalse(self.runnable.is_running())
        self.runnable._running = True
        self.assertTrue(self.runnable.is_running())
        self.runnable._running = None

    def test_start(self):
        self.runnable._running = True
        self.assertRaises(RuntimeError, lambda: self.runnable.start())
        self.runnable._running = None

        def next(self):
            raise StopIteration

        with patch('auklet.base.next', new=next):
            self.assertRaises(Exception, lambda: self.runnable.start())

        self.runnable._running = None

    def test_stop(self):
        self.runnable._running = None
        self.assertRaises(RuntimeError, lambda: self.runnable.stop())

        def next(self):
            raise StopIteration

        self.runnable._running = True
        with patch('auklet.base.next', new=next):
            self.runnable.stop()

    def test_run(self):
        self.assertTrue(self.run())

    def test___enter__(self):
        def start(self):
            global running
            running = True

        with patch('auklet.base.Runnable.start', new=start):
            self.runnable.__enter__()
            self.assertTrue(running)

    def test___exit__(self):
        pass


class Test(unittest.TestCase):
    def test_frame_stack(self):
        class FrameStack:
            f_back = None
        frame = FrameStack()
        self.assertNotEqual(frame_stack(frame), None)

    def test_get_mac(self):
        self.assertNotEqual(get_mac(), None)

    def test_get_commit_hash(self):
        with open(".auklet/version", "w") as my_file:
            my_file.write("commit_hash")
        self.assertNotEqual(get_commit_hash(), "")

        os.system("rm -R .auklet")
        self.assertEqual(get_commit_hash(), "")
        os.system("mkdir .auklet")
        os.system("touch .auklet/local.txt")
        os.system("touch .auklet/version")

    def test_get_abs_path(self):
        path = os.path.abspath(__file__)
        self.assertEqual(get_abs_path(path + "/.auklet"), path)

        with patch('os.path.abspath') as mock_abspath:
            mock_abspath.side_effect = IndexError
            self.assertEqual(get_abs_path(path), '')

    def test_get_device_ip(self):
        self.assertNotEqual(get_device_ip(), None)
        with patch('auklet.base.get_ip') as mock_error:
            mock_error.side_effect = IpifyException
            self.assertIsNone(get_device_ip())
            mock_error.side_effect = Exception
            self.assertIsNone(get_device_ip())

    def test_setup_thread_excepthook(self):
        pass


if __name__ == '__main__':
    unittest.main()



import factory


class MonitoringDataGenerator(object):
    def __init__(self, commitHash, id, publicIP, timestamp, application,
                 macAddressHash, lineNumber, nSamples, functionName, nCalls):
        self.commitHash = commitHash
        self.id = id
        self.publicIP = publicIP
        self.timestamp = timestamp
        self.application = application
        self.macAddressHash = macAddressHash

        self.lineNumber = lineNumber
        self.nSamples = nSamples
        self.functionName = functionName
        self.nCalls = nCalls

    def __str__(self):
        return '{"commitHash": "%s", ' \
               '"id": "%s", ' \
               '"publicIP": "%s", ' \
               '"timestamp": %d, ' \
               '"application": "%s", ' \
               '"macAddressHash": "%s", ' \
               '"callees": ' \
               '[{"lineNumber": %d, ' \
               '"nSamples": %d, ' \
               '"functionName": "%s", ' \
               '"nCalls": %d}]}' \
               % (self.commitHash, self.id, self.publicIP,
                  self.timestamp, self.application, self.macAddressHash,
                  self.lineNumber, self.nSamples, self.functionName,
                  self.nCalls)


class MonitoringDataFactory(factory.Factory):

    class Meta:
        model = MonitoringDataGenerator

    commitHash = "d0eb7082f4dd5dfce4c543e21299fb2e5774f70b"
    id = "30d376d2-fc7e-10d5-d51fe33373fd"
    publicIP = "187.2.167.60"
    timestamp = int(1531490785464)
    application = "nugvjtNBxHbjBnqbcFZvjn"
    macAddressHash = "d1dd34825af8599b78bd5f4a1d7d186e"
    lineNumber = int(836)
    nSamples = int(5745)
    functionName = "root"
    nCalls = 0


class ConfigGenerator(object):
    def __init__(self, brokers, prof_topic,
                 event_topic, log_topic, user_metrics_topic):
        self.brokers = brokers
        self.prof_topic = prof_topic
        self.event_topic = event_topic
        self.log_topic = log_topic
        self.user_metrics_topic = user_metrics_topic

    def __str__(self):
        return '{"brokers": ["%s"], "prof_topic": "%s", "event_topic": ' \
               '"%s", "log_topic": "%s", "user_metrics_topic": "%s"}' \
                % (self.brokers, self.prof_topic, self.event_topic,
                   self.log_topic, self.user_metrics_topic)


class ConfigFactory(factory.Factory):

    class Meta:
        model = ConfigGenerator

    brokers = "brokers-staging.feeds.auklet.io:9093"
    prof_topic = "profiler"
    event_topic = "events"
    log_topic = "logs"
    user_metrics_topic = "user_metrics"


class StackTraceGenerator(object):
    def __init__(self, functionName, lineNumber, nCalls, nSamples):
        self.functionName = functionName
        self.lineNumber = lineNumber
        self.nCalls = nCalls
        self.nSamples = nSamples

    def __str__(self):
        return '''{'callees': [],\n 'filePath': None,\n ''' \
               ''''functionName': '%s',\n 'lineNumber': %d,\n ''' \
               ''''nCalls': %d,\n 'nSamples': %d}''' \
               % (self.functionName, self.lineNumber,
                  self.nCalls, self.nSamples)


class StackTraceFactory(factory.Factory):

    class Meta:
        model = StackTraceGenerator

    functionName = "root"
    lineNumber = 1
    nCalls = 1
    nSamples = 1

class SingleNestedStackGenerator(object):
    def __init__(self, callees_functionName, callees_lineNumber,
                 callees_nCalls, callees_nSamples, functionName,
                 lineNumber, nCalls, nSamples):
        self.callees_functionName = callees_functionName
        self.callees_lineNumber = callees_lineNumber
        self.callees_nCalls = callees_nCalls
        self.callees_nSamples = callees_nSamples
        self.functionName = functionName
        self.lineNumber = lineNumber
        self.nCalls = nCalls
        self.nSamples = nSamples

    def __str__(self):
        return '''{'callees': [{'callees': [],\n''' \
               '''              'filePath': None,\n''' \
               '''              'functionName': '%s',\n''' \
               '''              'lineNumber': %d,\n''' \
               '''              'nCalls': %d,\n''' \
               '''              'nSamples': %d}],\n 'filePath': None,\n''' \
               ''' 'functionName': '%s',\n 'lineNumber': %d,\n''' \
               ''' 'nCalls': %d,\n 'nSamples': %d}''' \
               % (self.callees_functionName, self.callees_lineNumber,
                  self.callees_nCalls, self.callees_nSamples,
                  self.functionName, self.lineNumber, self.nCalls,
                  self.nSamples)


class SingleNestedStackTraceFactory(factory.Factory):

    class Meta:
        model = SingleNestedStackGenerator

    callees_functionName = ""
    callees_lineNumber = 0
    callees_nCalls = 1
    callees_nSamples = 1

    functionName = "root"
    lineNumber = 1
    nCalls = 1
    nSamples = 1
